@@ -5,6 +5,8 @@
  * Copyright (c) 2014-2016 Cisco Systems, Inc.  All Rights Reserved.
  */
 
+#define OPENSSL_API_COMPAT 0x10000000L
+
 #include <cjose/base64.h>
 #include <cjose/header.h>
 #include <cjose/jwe.h>
@@ -26,21 +28,17 @@
 #include "include/util_int.h"
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_set_cek_a256gcm(cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_set_cek_aes_gcm(cjose_jwe_t *jwe, const cjose_jwk_t *jwk, bool random, cjose_err *err);
 
-static bool _cjose_jwe_set_cek_aes_cbc(cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_set_cek_aes_cbc(cjose_jwe_t *jwe, const cjose_jwk_t *jwk, bool random, cjose_err *err);
 
-static bool
-_cjose_jwe_encrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_encrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
-static bool
-_cjose_jwe_decrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_decrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
-static bool
-_cjose_jwe_encrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_encrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
-static bool
-_cjose_jwe_decrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_decrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
 static bool
 _cjose_jwe_encrypt_ek_rsa_oaep(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
@@ -48,11 +46,9 @@ _cjose_jwe_encrypt_ek_rsa_oaep(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe
 static bool
 _cjose_jwe_decrypt_ek_rsa_oaep(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
-static bool
-_cjose_jwe_encrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_encrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
-static bool
-_cjose_jwe_decrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
+static bool _cjose_jwe_decrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
 static bool
 _cjose_jwe_encrypt_ek_ecdh_es(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
@@ -60,15 +56,15 @@ _cjose_jwe_encrypt_ek_ecdh_es(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe,
 static bool
 _cjose_jwe_decrypt_ek_ecdh_es(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err);
 
-static bool _cjose_jwe_set_iv_a256gcm(cjose_jwe_t *jwe, cjose_err *err);
+static bool _cjose_jwe_set_iv_aes_gcm(cjose_jwe_t *jwe, cjose_err *err);
 
 static bool _cjose_jwe_set_iv_aes_cbc(cjose_jwe_t *jwe, cjose_err *err);
 
-static bool _cjose_jwe_encrypt_dat_a256gcm(cjose_jwe_t *jwe, const uint8_t *plaintext, size_t plaintext_len, cjose_err *err);
+static bool _cjose_jwe_encrypt_dat_aes_gcm(cjose_jwe_t *jwe, const uint8_t *plaintext, size_t plaintext_len, cjose_err *err);
 
 static bool _cjose_jwe_encrypt_dat_aes_cbc(cjose_jwe_t *jwe, const uint8_t *plaintext, size_t plaintext_len, cjose_err *err);
 
-static bool _cjose_jwe_decrypt_dat_a256gcm(cjose_jwe_t *jwe, cjose_err *err);
+static bool _cjose_jwe_decrypt_dat_aes_gcm(cjose_jwe_t *jwe, cjose_err *err);
 
 static bool _cjose_jwe_decrypt_dat_aes_cbc(cjose_jwe_t *jwe, cjose_err *err);
 
@@ -162,13 +158,28 @@ static size_t _keylen_from_enc(const char *alg)
 {
     size_t keylen = 0;
 
-    if (0 == strcmp(alg, CJOSE_HDR_ENC_A256GCM)) {
+    if (0 == strcmp(alg, CJOSE_HDR_ENC_A128GCM))
+    {
+        keylen = 128;
+    }
+    else if (0 == strcmp(alg, CJOSE_HDR_ENC_A192GCM))
+    {
+        keylen = 192;
+    }
+    else if (0 == strcmp(alg, CJOSE_HDR_ENC_A256GCM))
+    {
         keylen = 256;
-    } else if (0 == strcmp(alg, CJOSE_HDR_ENC_A128CBC_HS256)) {
+    }
+    else if (0 == strcmp(alg, CJOSE_HDR_ENC_A128CBC_HS256))
+    {
         keylen = 256;
-    } else if (0 == strcmp(alg, CJOSE_HDR_ENC_A192CBC_HS384)) {
+    }
+    else if (0 == strcmp(alg, CJOSE_HDR_ENC_A192CBC_HS384))
+    {
         keylen = 384;
-    } else if (0 == strcmp(alg, CJOSE_HDR_ENC_A256CBC_HS512)) {
+    }
+    else if (0 == strcmp(alg, CJOSE_HDR_ENC_A256CBC_HS512))
+    {
         keylen = 512;
     }
 
@@ -268,12 +279,13 @@ static bool _cjose_jwe_validate_enc(cjose_jwe_t *jwe, cjose_header_t *protected_
         return false;
     }
 
-    if (strcmp(enc, CJOSE_HDR_ENC_A256GCM) == 0)
+    if ((strcmp(enc, CJOSE_HDR_ENC_A128GCM) == 0) || (strcmp(enc, CJOSE_HDR_ENC_A192GCM) == 0)
+        || (strcmp(enc, CJOSE_HDR_ENC_A256GCM) == 0))
     {
-        jwe->fns.set_cek = _cjose_jwe_set_cek_a256gcm;
-        jwe->fns.set_iv = _cjose_jwe_set_iv_a256gcm;
-        jwe->fns.encrypt_dat = _cjose_jwe_encrypt_dat_a256gcm;
-        jwe->fns.decrypt_dat = _cjose_jwe_decrypt_dat_a256gcm;
+        jwe->fns.set_cek = _cjose_jwe_set_cek_aes_gcm;
+        jwe->fns.set_iv = _cjose_jwe_set_iv_aes_gcm;
+        jwe->fns.encrypt_dat = _cjose_jwe_encrypt_dat_aes_gcm;
+        jwe->fns.decrypt_dat = _cjose_jwe_decrypt_dat_aes_gcm;
     }
     if ((strcmp(enc, CJOSE_HDR_ENC_A128CBC_HS256) == 0) || (strcmp(enc, CJOSE_HDR_ENC_A192CBC_HS384) == 0)
         || (strcmp(enc, CJOSE_HDR_ENC_A256CBC_HS512) == 0))
@@ -359,21 +371,36 @@ static bool _cjose_jwe_validate_alg(cjose_header_t *protected_header,
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_set_cek_a256gcm(cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
+static bool _cjose_jwe_set_cek_aes_gcm(cjose_jwe_t *jwe, const cjose_jwk_t *jwk, bool random, cjose_err *err)
 {
-    // 256 bits = 32 bytes
-    static const size_t keysize = 32;
-
     if (NULL != jwe->cek)
     {
         return true;
     }
 
+    // make sure we have an enc header
+    json_t *enc_obj = json_object_get(jwe->hdr, CJOSE_HDR_ENC);
+    if (NULL == enc_obj)
+    {
+        CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
+        return false;
+    }
+    const char *enc = json_string_value(enc_obj);
+
+    // determine the CEK key size based on the encryption algorithm
+    size_t keysize = 0;
+    if (strcmp(enc, CJOSE_HDR_ENC_A128GCM) == 0)
+        keysize = 16;
+    if (strcmp(enc, CJOSE_HDR_ENC_A192GCM) == 0)
+        keysize = 24;
+    if (strcmp(enc, CJOSE_HDR_ENC_A256GCM) == 0)
+        keysize = 32;
+
     // if no JWK is provided, generate a random key
     if (NULL == jwk)
     {
         _cjose_release_cek(&jwe->cek, jwe->cek_len);
-        if (!_cjose_jwe_malloc(keysize, true, &jwe->cek, err))
+        if (!_cjose_jwe_malloc(keysize, random, &jwe->cek, err))
         {
             return false;
         }
@@ -402,7 +429,7 @@ static bool _cjose_jwe_set_cek_a256gcm(cjose_jwe_t *jwe, const cjose_jwk_t *jwk,
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_set_cek_aes_cbc(cjose_jwe_t *jwe, const cjose_jwk_t *dummy_set_to_null_for_random, cjose_err *err)
+static bool _cjose_jwe_set_cek_aes_cbc(cjose_jwe_t *jwe, const cjose_jwk_t *jwk, bool random, cjose_err *err)
 {
 
     if (NULL != jwe->cek)
@@ -420,29 +447,50 @@ static bool _cjose_jwe_set_cek_aes_cbc(cjose_jwe_t *jwe, const cjose_jwk_t *dumm
     const char *enc = json_string_value(enc_obj);
 
     // determine the CEK key size based on the encryption algorithm
+    size_t keysize = 0;
     if (strcmp(enc, CJOSE_HDR_ENC_A128CBC_HS256) == 0)
-        jwe->cek_len = 32;
+        keysize = 32;
     if (strcmp(enc, CJOSE_HDR_ENC_A192CBC_HS384) == 0)
-        jwe->cek_len = 48;
+        keysize = 48;
     if (strcmp(enc, CJOSE_HDR_ENC_A256CBC_HS512) == 0)
-        jwe->cek_len = 64;
+        keysize = 64;
 
-    // allocate memory for the CEK and fill with random bytes or 0's
-    _cjose_release_cek(&jwe->cek, jwe->cek_len);
-    if (!_cjose_jwe_malloc(jwe->cek_len, dummy_set_to_null_for_random == NULL, &jwe->cek, err))
+    if (NULL == jwk)
     {
-        return false;
+        // allocate memory for the CEK and fill with random bytes or 0's
+        _cjose_release_cek(&jwe->cek, jwe->cek_len);
+        if (!_cjose_jwe_malloc(keysize, !random, &jwe->cek, err))
+        {
+            return false;
+        }
+        jwe->cek_len = keysize;
     }
+    else
+    {
+        // if a JWK is provided, it must be a symmetric key of correct size
+        if (CJOSE_JWK_KTY_OCT != cjose_jwk_get_kty(jwk, err) || jwk->keysize != keysize * 8 || NULL == jwk->keydata)
+        {
+            CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
+            return false;
+        }
 
+        // copy the key material directly from jwk to the jwe->cek
+        _cjose_release_cek(&jwe->cek, jwe->cek_len);
+        if (!_cjose_jwe_malloc(keysize, false, &jwe->cek, err))
+        {
+            return false;
+        }
+        memcpy(jwe->cek, jwk->keydata, keysize);
+        jwe->cek_len = keysize;
+    }
     return true;
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool
-_cjose_jwe_encrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
+static bool _cjose_jwe_encrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     // for direct encryption, JWE sec 5.1, step 6: let CEK be the symmetric key.
-    if (!jwe->fns.set_cek(jwe, jwk, err))
+    if (!jwe->fns.set_cek(jwe, jwk, false, err))
     {
         return false;
     }
@@ -455,17 +503,15 @@ _cjose_jwe_encrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, con
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool
-_cjose_jwe_decrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
+static bool _cjose_jwe_decrypt_ek_dir(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     // do not try and decrypt the ek. that's impossible.
     // instead... only try to realize the truth.  there is no ek.
-    return jwe->fns.set_cek(jwe, jwk, err);
+    return jwe->fns.set_cek(jwe, jwk, false, err);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool
-_cjose_jwe_encrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
+static bool _cjose_jwe_encrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     if (NULL == jwe || NULL == jwk)
     {
@@ -481,7 +527,7 @@ _cjose_jwe_encrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe,
     }
 
     // generate random CEK
-    if (!jwe->fns.set_cek(jwe, NULL, err))
+    if (!jwe->fns.set_cek(jwe, NULL, true, err))
     {
         return false;
     }
@@ -513,8 +559,7 @@ _cjose_jwe_encrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe,
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool
-_cjose_jwe_decrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
+static bool _cjose_jwe_decrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     if (NULL == jwe || NULL == jwk)
     {
@@ -537,8 +582,7 @@ _cjose_jwe_decrypt_ek_aes_kw(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe,
         return false;
     }
 
-    // generate empty CEK so the the right amount of memory is allocated (abuse JWK parameter to empty)
-    if (!jwe->fns.set_cek(jwe, (const cjose_jwk_t *)1, err))
+    if (!jwe->fns.set_cek(jwe, NULL, false, err))
     {
         return false;
     }
@@ -577,7 +621,7 @@ static bool _cjose_jwe_encrypt_ek_rsa_padding(
     }
 
     // generate random cek
-    if (!jwe->fns.set_cek(jwe, NULL, err))
+    if (!jwe->fns.set_cek(jwe, NULL, true, err))
     {
         return false;
     }
@@ -627,6 +671,15 @@ static bool _cjose_jwe_decrypt_ek_rsa_padding(
         return false;
     }
 
+    // jwk must have the necessary private parts set
+    BIGNUM *rsa_n = NULL, *rsa_e = NULL, *rsa_d = NULL;
+    _cjose_jwk_rsa_get((RSA *)jwk->keydata, &rsa_n, &rsa_e, &rsa_d);
+    if (NULL == rsa_e || NULL == rsa_n || NULL == rsa_d)
+    {
+        CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
+        return false;
+    }
+
     // we don't know the size of the key to expect, but must be < RSA_size
     _cjose_release_cek(&jwe->cek, jwe->cek_len);
     size_t buflen = RSA_size((RSA *)jwk->keydata);
@@ -636,13 +689,15 @@ static bool _cjose_jwe_decrypt_ek_rsa_padding(
     }
 
     // decrypt the CEK using RSA v1.5 or OAEP padding
-    jwe->cek_len = RSA_private_decrypt(recipient->enc_key.raw_len, recipient->enc_key.raw, jwe->cek, (RSA *)jwk->keydata, padding);
-    if (-1 == jwe->cek_len)
+    int len = RSA_private_decrypt(recipient->enc_key.raw_len, recipient->enc_key.raw, jwe->cek, (RSA *)jwk->keydata, padding);
+    if (-1 == len)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
         return false;
     }
 
+    jwe->cek_len = len;
+
     return true;
 }
 
@@ -661,24 +716,19 @@ _cjose_jwe_decrypt_ek_rsa_oaep(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool
-_cjose_jwe_encrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
+static bool _cjose_jwe_encrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     return _cjose_jwe_encrypt_ek_rsa_padding(recipient, jwe, jwk, RSA_PKCS1_PADDING, err);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool
-_cjose_jwe_decrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
+static bool _cjose_jwe_decrypt_ek_rsa1_5(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     return _cjose_jwe_decrypt_ek_rsa_padding(recipient, jwe, jwk, RSA_PKCS1_PADDING, err);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_encrypt_ek_ecdh_es(_jwe_int_recipient_t *recipient,
-                                          cjose_jwe_t *jwe,
-                                          const cjose_jwk_t *jwk,
-                                          cjose_err *err)
+static bool _cjose_jwe_encrypt_ek_ecdh_es(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     cjose_jwk_t *epk_jwk = NULL;
     char *epk_json = NULL;
@@ -750,10 +800,7 @@ cjose_encrypt_ek_ecdh_es_finish:
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_decrypt_ek_ecdh_es(_jwe_int_recipient_t *recipient,
-                                          cjose_jwe_t *jwe,
-                                          const cjose_jwk_t *jwk,
-                                          cjose_err *err)
+static bool _cjose_jwe_decrypt_ek_ecdh_es(_jwe_int_recipient_t *recipient, cjose_jwe_t *jwe, const cjose_jwk_t *jwk, cjose_err *err)
 {
     cjose_jwk_t *epk_jwk = NULL;
     uint8_t *secret = NULL;
@@ -825,7 +872,7 @@ cjose_decrypt_ek_ecdh_es_finish:
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_set_iv_a256gcm(cjose_jwe_t *jwe, cjose_err *err)
+static bool _cjose_jwe_set_iv_aes_gcm(cjose_jwe_t *jwe, cjose_err *err)
 {
     // generate IV as random 96 bit value
     cjose_get_dealloc()(jwe->enc_iv.raw);
@@ -848,23 +895,25 @@ static bool _cjose_jwe_set_iv_aes_cbc(cjose_jwe_t *jwe, cjose_err *err)
         CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
         return false;
     }
-    const char *enc = json_string_value(enc_obj);
-
     cjose_get_dealloc()(jwe->enc_iv.raw);
-    jwe->enc_iv.raw_len = 0;
 
-    if (strcmp(enc, CJOSE_HDR_ENC_A128CBC_HS256) == 0)
-        jwe->enc_iv.raw_len = 16;
-    if (strcmp(enc, CJOSE_HDR_ENC_A192CBC_HS384) == 0)
-        jwe->enc_iv.raw_len = 24;
-    if (strcmp(enc, CJOSE_HDR_ENC_A256CBC_HS512) == 0)
-        jwe->enc_iv.raw_len = 32;
-
-    if (jwe->enc_iv.raw_len == 0)
-    {
-        CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
-        return false;
-    }
+    // RFC 7516 (https://tools.ietf.org/html/rfc7516) is unclear about
+    // the size of the IV for AES-CBC. In section 5.1
+    // (https://tools.ietf.org/html/rfc7516#section-5.1), they state in no. 9.:
+    // "Generate a random JWE Initialization Vector of the correct size
+    // for the content encryption algorithm"
+    // And in the example in A.2.4 (https://tools.ietf.org/html/rfc7516#appendix-A.2.4)
+    // they provide an example for AES128-CBC, which results (naturally) in the IV size of 128Bit.
+    //
+    // The CISCO implementation chooses for the size of the IV the key size of the
+    // cipher algorithm, which seems to be wrong.
+    //
+    // According to RFC 3602 section 3 (https://tools.ietf.org/html/rfc3602#section-3):
+    // "The IV field MUST be the same size as the block size of the cipher algorithm being used."
+    // And because the block size for AES cipher is always 16 Byte, the IV must be 16 Byte long.
+    //
+    // IV size for AES CBC is always 16 Byte
+    jwe->enc_iv.raw_len = 16;
 
     // generate IV as random iv_size * 8 bit value
     if (!_cjose_jwe_malloc(jwe->enc_iv.raw_len, true, &jwe->enc_iv.raw, err))
@@ -875,7 +924,7 @@ static bool _cjose_jwe_set_iv_aes_cbc(cjose_jwe_t *jwe, cjose_err *err)
     return true;
 }
 
-#if (CJOSE_OPENSSL_11X)
+#if defined(CJOSE_OPENSSL_11X)
 #define CJOSE_EVP_CTRL_GCM_GET_TAG EVP_CTRL_AEAD_GET_TAG
 #define CJOSE_EVP_CTRL_GCM_SET_TAG EVP_CTRL_AEAD_SET_TAG
 #else
@@ -884,18 +933,35 @@ static bool _cjose_jwe_set_iv_aes_cbc(cjose_jwe_t *jwe, cjose_err *err)
 #endif
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_encrypt_dat_a256gcm(cjose_jwe_t *jwe, const uint8_t *plaintext, size_t plaintext_len, cjose_err *err)
+static bool _cjose_jwe_encrypt_dat_aes_gcm(cjose_jwe_t *jwe, const uint8_t *plaintext, size_t plaintext_len, cjose_err *err)
 {
     EVP_CIPHER_CTX *ctx = NULL;
 
+    // make sure we have an enc header
+    json_t *enc_obj = json_object_get(jwe->hdr, CJOSE_HDR_ENC);
+    if (NULL == enc_obj)
+    {
+        CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
+        return false;
+    }
+    const char *enc = json_string_value(enc_obj);
+
     if (NULL == plaintext)
     {
         CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
         goto _cjose_jwe_encrypt_dat_fail;
     }
 
-    // get A256GCM cipher
-    const EVP_CIPHER *cipher = EVP_aes_256_gcm();
+    // get AES GCM cipher
+    const EVP_CIPHER *cipher = NULL;
+
+    if (strcmp(enc, CJOSE_HDR_ENC_A128GCM) == 0)
+        cipher = EVP_aes_128_gcm();
+    if (strcmp(enc, CJOSE_HDR_ENC_A192GCM) == 0)
+        cipher = EVP_aes_192_gcm();
+    if (strcmp(enc, CJOSE_HDR_ENC_A256GCM) == 0)
+        cipher = EVP_aes_256_gcm();
+
     if (NULL == cipher)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
@@ -911,7 +977,7 @@ static bool _cjose_jwe_encrypt_dat_a256gcm(cjose_jwe_t *jwe, const uint8_t *plai
     }
     EVP_CIPHER_CTX_init(ctx);
 
-    // initialize context for encryption using A256GCM cipher and CEK and IV
+    // initialize context for encryption using AES GCM cipher and CEK and IV
     if (EVP_EncryptInit_ex(ctx, cipher, NULL, jwe->cek, jwe->enc_iv.raw) != 1)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
@@ -919,8 +985,9 @@ static bool _cjose_jwe_encrypt_dat_a256gcm(cjose_jwe_t *jwe, const uint8_t *plai
     }
 
     // we need the header in base64url encoding as input for encryption
-    if ((NULL == jwe->enc_header.b64u) && (!cjose_base64url_encode((const uint8_t *)jwe->enc_header.raw, jwe->enc_header.raw_len,
-                                                                   &jwe->enc_header.b64u, &jwe->enc_header.b64u_len, err)))
+    if ((NULL == jwe->enc_header.b64u)
+        && (!cjose_base64url_encode((const uint8_t *)jwe->enc_header.raw, jwe->enc_header.raw_len, &jwe->enc_header.b64u,
+                                    &jwe->enc_header.b64u_len, err)))
     {
         goto _cjose_jwe_encrypt_dat_fail;
     }
@@ -1113,8 +1180,9 @@ static bool _cjose_jwe_encrypt_dat_aes_cbc(cjose_jwe_t *jwe, const uint8_t *plai
     }
 
     // we need the header in base64url encoding as input for encryption
-    if ((NULL == jwe->enc_header.b64u) && (!cjose_base64url_encode((const uint8_t *)jwe->enc_header.raw, jwe->enc_header.raw_len,
-                                                                   &jwe->enc_header.b64u, &jwe->enc_header.b64u_len, err)))
+    if ((NULL == jwe->enc_header.b64u)
+        && (!cjose_base64url_encode((const uint8_t *)jwe->enc_header.raw, jwe->enc_header.raw_len, &jwe->enc_header.b64u,
+                                    &jwe->enc_header.b64u_len, err)))
     {
         goto _cjose_jwe_encrypt_dat_aes_cbc_fail;
     }
@@ -1174,16 +1242,33 @@ _cjose_jwe_encrypt_dat_aes_cbc_fail:
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-static bool _cjose_jwe_decrypt_dat_a256gcm(cjose_jwe_t *jwe, cjose_err *err)
+static bool _cjose_jwe_decrypt_dat_aes_gcm(cjose_jwe_t *jwe, cjose_err *err)
 {
     EVP_CIPHER_CTX *ctx = NULL;
 
-    // get A256GCM cipher
-    const EVP_CIPHER *cipher = EVP_aes_256_gcm();
+    // make sure we have an enc header
+    json_t *enc_obj = json_object_get(jwe->hdr, CJOSE_HDR_ENC);
+    if (NULL == enc_obj)
+    {
+        CJOSE_ERROR(err, CJOSE_ERR_INVALID_ARG);
+        return false;
+    }
+    const char *enc = json_string_value(enc_obj);
+
+    // get AES GCM cipher
+    const EVP_CIPHER *cipher = NULL;
+
+    if (strcmp(enc, CJOSE_HDR_ENC_A128GCM) == 0)
+        cipher = EVP_aes_128_gcm();
+    if (strcmp(enc, CJOSE_HDR_ENC_A192GCM) == 0)
+        cipher = EVP_aes_192_gcm();
+    if (strcmp(enc, CJOSE_HDR_ENC_A256GCM) == 0)
+        cipher = EVP_aes_256_gcm();
+
     if (NULL == cipher)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
 
     // instantiate and initialize a new openssl cipher context
@@ -1191,22 +1276,22 @@ static bool _cjose_jwe_decrypt_dat_a256gcm(cjose_jwe_t *jwe, cjose_err *err)
     if (NULL == ctx)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
     EVP_CIPHER_CTX_init(ctx);
 
-    // initialize context for decryption using A256GCM cipher and CEK and IV
+    // initialize context for decryption using AES GCM cipher and CEK and IV
     if (EVP_DecryptInit_ex(ctx, cipher, NULL, jwe->cek, jwe->enc_iv.raw) != 1)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
 
     // set the expected GCM-mode authentication tag
     if (EVP_CIPHER_CTX_ctrl(ctx, CJOSE_EVP_CTRL_GCM_SET_TAG, jwe->enc_auth_tag.raw_len, jwe->enc_auth_tag.raw) != 1)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
 
     // set GCM mode AAD data (hdr_b64u) by setting "out" to NULL
@@ -1215,7 +1300,7 @@ static bool _cjose_jwe_decrypt_dat_a256gcm(cjose_jwe_t *jwe, cjose_err *err)
         || bytes_decrypted != jwe->enc_header.b64u_len)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
 
     // allocate buffer for the plaintext
@@ -1223,14 +1308,14 @@ static bool _cjose_jwe_decrypt_dat_a256gcm(cjose_jwe_t *jwe, cjose_err *err)
     jwe->dat_len = jwe->enc_ct.raw_len;
     if (!_cjose_jwe_malloc(jwe->dat_len, false, &jwe->dat, err))
     {
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
 
     // decrypt ciphertext to plaintext buffer
     if (EVP_DecryptUpdate(ctx, jwe->dat, &bytes_decrypted, jwe->enc_ct.raw, jwe->enc_ct.raw_len) != 1)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
     jwe->dat_len = bytes_decrypted;
 
@@ -1238,13 +1323,13 @@ static bool _cjose_jwe_decrypt_dat_a256gcm(cjose_jwe_t *jwe, cjose_err *err)
     if (EVP_DecryptFinal_ex(ctx, NULL, &bytes_decrypted) != 1)
     {
         CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
-        goto _cjose_jwe_decrypt_dat_a256gcm_fail;
+        goto _cjose_jwe_decrypt_dat_aes_gcm_fail;
     }
 
     EVP_CIPHER_CTX_free(ctx);
     return true;
 
-_cjose_jwe_decrypt_dat_a256gcm_fail:
+_cjose_jwe_decrypt_dat_aes_gcm_fail:
     if (NULL != ctx)
     {
         EVP_CIPHER_CTX_free(ctx);
@@ -1355,26 +1440,37 @@ _cjose_jwe_decrypt_dat_aes_cbc_fail:
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-cjose_jwe_t *cjose_jwe_encrypt(
-    const cjose_jwk_t *jwk, cjose_header_t *protected_header, const uint8_t *plaintext, size_t plaintext_len, cjose_err *err)
+cjose_jwe_t *cjose_jwe_encrypt_iv(const cjose_jwk_t *jwk,
+                                  cjose_header_t *protected_header,
+                                  const uint8_t *iv,
+                                  size_t iv_len,
+                                  const uint8_t *plaintext,
+                                  size_t plaintext_len,
+                                  cjose_err *err)
 {
 
-    cjose_jwe_recipient_t rec = {
-        .jwk = jwk,
-        .unprotected_header = NULL
-    };
+    cjose_jwe_recipient_t rec = { .jwk = jwk, .unprotected_header = NULL };
 
-    return cjose_jwe_encrypt_multi(&rec, 1, protected_header, NULL, plaintext, plaintext_len, err);
+    return cjose_jwe_encrypt_multi_iv(&rec, 1, protected_header, NULL, iv, iv_len, plaintext, plaintext_len, err);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
-cjose_jwe_t *cjose_jwe_encrypt_multi(const cjose_jwe_recipient_t * recipients,
-                                    size_t recipient_count,
-                                    cjose_header_t *protected_header,
-                                    cjose_header_t *shared_unprotected_header,
-                                    const uint8_t *plaintext,
-                                    size_t plaintext_len,
-                                    cjose_err *err)
+cjose_jwe_t *cjose_jwe_encrypt(
+    const cjose_jwk_t *jwk, cjose_header_t *protected_header, const uint8_t *plaintext, size_t plaintext_len, cjose_err *err)
+{
+    return cjose_jwe_encrypt_iv(jwk, protected_header, NULL, 0, plaintext, plaintext_len, err);
+}
+
+////////////////////////////////////////////////////////////////////////////////
+cjose_jwe_t *cjose_jwe_encrypt_multi_iv(const cjose_jwe_recipient_t *recipients,
+                                        size_t recipient_count,
+                                        cjose_header_t *protected_header,
+                                        cjose_header_t *shared_unprotected_header,
+                                        const uint8_t *iv,
+                                        size_t iv_len,
+                                        const uint8_t *plaintext,
+                                        size_t plaintext_len,
+                                        cjose_err *err)
 {
     cjose_jwe_t *jwe = NULL;
 
@@ -1452,10 +1548,24 @@ cjose_jwe_t *cjose_jwe_encrypt_multi(const cjose_jwe_recipient_t * recipients,
     }
 
     // build JWE initialization vector
-    if (!jwe->fns.set_iv(jwe, err))
+    if (iv == NULL)
     {
-        cjose_jwe_release(jwe);
-        return NULL;
+        if (!jwe->fns.set_iv(jwe, err))
+        {
+            cjose_jwe_release(jwe);
+            return NULL;
+        }
+    }
+    else
+    {
+        cjose_get_dealloc()(jwe->enc_iv.raw);
+        jwe->enc_iv.raw_len = iv_len;
+        if (!_cjose_jwe_malloc(jwe->enc_iv.raw_len, false, &jwe->enc_iv.raw, err))
+        {
+            cjose_jwe_release(jwe);
+            return NULL;
+        }
+        memcpy(jwe->enc_iv.raw, iv, iv_len);
     }
 
     // build JWE encrypted data and authentication tag
@@ -1470,6 +1580,19 @@ cjose_jwe_t *cjose_jwe_encrypt_multi(const cjose_jwe_recipient_t * recipients,
     return jwe;
 }
 
+////////////////////////////////////////////////////////////////////////////////
+cjose_jwe_t *cjose_jwe_encrypt_multi(const cjose_jwe_recipient_t *recipients,
+                                     size_t recipient_count,
+                                     cjose_header_t *protected_header,
+                                     cjose_header_t *shared_unprotected_header,
+                                     const uint8_t *plaintext,
+                                     size_t plaintext_len,
+                                     cjose_err *err)
+{
+    return cjose_jwe_encrypt_multi_iv(recipients, recipient_count, protected_header, shared_unprotected_header, NULL, 0, plaintext,
+                                      plaintext_len, err);
+}
+
 ////////////////////////////////////////////////////////////////////////////////
 void cjose_jwe_release(cjose_jwe_t *jwe)
 {
@@ -1617,7 +1740,7 @@ char *cjose_jwe_export_json(cjose_jwe_t *jwe, cjose_err *err)
         }
     }
 
-    char *json_str = json_dumps(form, 0);
+    char *json_str = json_dumps(form, JSON_PRESERVE_ORDER);
     if (NULL == json_str)
     {
         CJOSE_ERROR(err, CJOSE_ERR_NO_MEMORY);
@@ -1927,6 +2050,11 @@ uint8_t *cjose_jwe_decrypt_multi(cjose_jwe_t *jwe, cjose_key_locator key_locator
         {
             cek_len = jwe->cek_len;
             cek = cjose_get_alloc()(cek_len);
+            if (!cek)
+            {
+                CJOSE_ERROR(err, CJOSE_ERR_NO_MEMORY);
+                return NULL;
+            }
             memcpy(cek, jwe->cek, cek_len);
         }
         else
@@ -1939,6 +2067,12 @@ uint8_t *cjose_jwe_decrypt_multi(cjose_jwe_t *jwe, cjose_key_locator key_locator
         }
     }
 
+    if (NULL == jwe->cek)
+    {
+        CJOSE_ERROR(err, CJOSE_ERR_CRYPTO);
+        goto _cjose_jwe_decrypt_multi_fail;
+    }
+
     // decrypt JWE encrypted data
     if (!jwe->fns.decrypt_dat(jwe, err))
     {
